/*
 * Copyright 2023 The Android Open Source Project
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package androidx.tv.integration.presentation

import androidx.compose.foundation.layout.Arrangement
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.PaddingValues
import androidx.compose.foundation.layout.padding
import androidx.compose.runtime.Composable
import androidx.compose.runtime.getValue
import androidx.compose.runtime.mutableStateOf
import androidx.compose.runtime.remember
import androidx.compose.runtime.setValue
import androidx.compose.ui.Modifier
import androidx.compose.ui.focus.onFocusChanged
import androidx.compose.ui.graphics.Color
import androidx.compose.ui.unit.dp
import androidx.compose.ui.unit.sp
import androidx.tv.foundation.lazy.list.TvLazyRow
import androidx.tv.material3.ExperimentalTvMaterial3Api
import androidx.tv.material3.Text

@OptIn(ExperimentalTvMaterial3Api::class)
@Composable
fun AppLazyRow(
    title: String,
    items: List<Movie>,
    modifier: Modifier = Modifier,
    drawItem: @Composable (movie: Movie, index: Int, modifier: Modifier) -> Unit
) {
    val paddingLeft = 58.dp
    var hasFocus by remember { mutableStateOf(false) }

    val focusRestorerModifiers = createCustomInitialFocusRestorerModifiers()

    Column(modifier = modifier.onFocusChanged { hasFocus = it.hasFocus }) {
        Text(
            text = title,
            color = if (hasFocus) Color.White else Color.White.copy(alpha = 0.8f),
            fontSize = 14.sp,
            modifier = Modifier.padding(start = paddingLeft)
        )

        AppSpacer(height = 12.dp)

        TvLazyRow(
            contentPadding = PaddingValues(horizontal = paddingLeft),
            horizontalArrangement = Arrangement.spacedBy(20.dp),
            modifier = focusRestorerModifiers.parentModifier,
        ) {
            items.forEachIndexed { index, movie ->
                item {
                    drawItem(
                        movie,
                        index,
                        Modifier.ifElse(index == 0, focusRestorerModifiers.childModifier)
                    )
                }
            }
        }
    }
}
